@@ -21,7 +21,7 @@ use std::sync::{Arc, Mutex};
 use std::thread;
 
 use case_result::{CaseResult, CaseStatus};
-use find_file::{find_tests, read_test_files, TestHarness};
+use find_file::TestHarness;
 use reporter::{DefaultReporter, InteractiveReporter, Reporter};
 use snapshot::{SnapshotAction, SnapshotCollection, TestSnapshots};
 use test_case::TestCase;
@@ -61,16 +61,10 @@ fn run_test_rule_impl<R: Reporter + Send>(arg: TestArg, reporter: R) -> Result<(
     snapshots,
     path_map,
   } = if let Some(test_dirname) = arg.test_dir {
-    let base_dir = std::env::current_dir()?;
     let snapshot_dirname = arg.snapshot_dir.as_deref();
-    read_test_files(
-      &base_dir,
-      &test_dirname,
-      snapshot_dirname,
-      arg.filter.as_ref(),
-    )?
+    TestHarness::from_dir(&test_dirname, snapshot_dirname, arg.filter.as_ref())?
   } else {
-    find_tests(arg.config, arg.filter.as_ref())?
+    TestHarness::from_config(arg.config, arg.filter.as_ref())?
   };
   let snapshots = (!arg.skip_snapshot_tests).then_some(snapshots);
   let reporter = &Arc::new(Mutex::new(reporter));
